package cn.iocoder.yudao.module.cash.service.paymentinfo;

import org.springframework.stereotype.Service;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;
import org.springframework.transaction.annotation.Transactional;

import java.util.*;
import cn.iocoder.yudao.module.cash.controller.admin.paymentinfo.vo.*;
import cn.iocoder.yudao.module.cash.dal.dataobject.paymentinfo.PaymentInfoDO;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.pojo.PageParam;
import cn.iocoder.yudao.framework.common.util.object.BeanUtils;

import cn.iocoder.yudao.module.cash.dal.mysql.paymentinfo.PaymentInfoMapper;

import static cn.iocoder.yudao.framework.common.exception.util.ServiceExceptionUtil.exception;
import static cn.iocoder.yudao.module.cash.enums.ErrorCodeConstants.*;

/**
 * 付款信息 Service 实现类
 *
 * @author dp
 */
@Service
@Validated
public class PaymentInfoServiceImpl implements PaymentInfoService {

    @Resource
    private PaymentInfoMapper paymentInfoMapper;

    @Override
    public Long createPaymentInfo(PaymentInfoSaveReqVO createReqVO) {
        // 插入
        PaymentInfoDO paymentInfo = BeanUtils.toBean(createReqVO, PaymentInfoDO.class);
        paymentInfoMapper.insert(paymentInfo);
        // 返回
        return paymentInfo.getId();
    }

    @Override
    public void updatePaymentInfo(PaymentInfoSaveReqVO updateReqVO) {
        // 校验存在
        validatePaymentInfoExists(updateReqVO.getId());
        // 更新
        PaymentInfoDO updateObj = BeanUtils.toBean(updateReqVO, PaymentInfoDO.class);
        paymentInfoMapper.updateById(updateObj);
    }

    @Override
    public void deletePaymentInfo(Long id) {
        // 校验存在
        validatePaymentInfoExists(id);
        // 删除
        paymentInfoMapper.deleteById(id);
    }

    private void validatePaymentInfoExists(Long id) {
        if (paymentInfoMapper.selectById(id) == null) {
            throw exception(PAYMENT_INFO_NOT_EXISTS);
        }
    }

    @Override
    public PaymentInfoDO getPaymentInfo(Long id) {
        return paymentInfoMapper.selectById(id);
    }

    @Override
    public PageResult<PaymentInfoDO> getPaymentInfoPage(PaymentInfoPageReqVO pageReqVO) {
        return paymentInfoMapper.selectPage(pageReqVO);
    }

}